/*! Tripetto standard Bootstrap collector 1.0.26-2 - Copyright (C) 2019 Tripetto B.V. - All Rights Reserved */
//   ../../../styles/interface

declare module "tripetto-collector-standard-bootstrap" {
    export { Collector } from "tripetto-collector-standard-bootstrap/collector";
    export { ICollectorStyles } from "tripetto-collector-standard-bootstrap/styles/interface";
    export { ICollectorOverrides } from "tripetto-collector-standard-bootstrap/interfaces/overrides";
    export { ICollectorSnapshot } from "tripetto-collector-standard-bootstrap/interfaces/snapshot";
    export { IBlockRenderer } from "tripetto-collector-standard-bootstrap/interfaces/renderer";
    export { IBlockHelper } from "tripetto-collector-standard-bootstrap/interfaces/block";
    export { usePauseToEmailDialog } from "tripetto-collector-standard-bootstrap/components/pause";
    export { run } from "tripetto-collector-standard-bootstrap/run";
}

declare module "tripetto-collector-standard-bootstrap/collector" {
    import * as React from "react";
    import { IDefinition, IL10n, ISnapshot, Instance } from "tripetto-collector";
    import { ICollectorState } from "tripetto-collector-standard-bootstrap/interfaces/state";
    import { ICollectorStyles } from "tripetto-collector-standard-bootstrap/styles/interface";
    import { ICollectorOverrides } from "tripetto-collector-standard-bootstrap/interfaces/overrides";
    import { ICollectorSnapshot } from "tripetto-collector-standard-bootstrap/interfaces/snapshot";
    import "bootstrap";
    import "./collector.scss";
    export class Collector extends React.PureComponent<{
        /** Specifies the definition to run. */
        readonly definition: IDefinition;
        /** Specifies the snapshot that should be restored. */
        readonly snapshot?: ISnapshot<ICollectorSnapshot>;
        /** Specifies the styles. */
        readonly styles?: ICollectorStyles;
        /** Specifies the localization information. */
        readonly l10n?: IL10n;
        /** Invoked when the l10n information is updated. */
        readonly onL10n?: (l: IL10n) => Promise<void>;
        /** Specifies the overrides for the collector. */
        readonly overrides?: ICollectorOverrides;
        /** Specifies the view mode (`normal` by default). */
        readonly view?: "normal" | "preview" | "test";
        /** Specifies how the collector is used (defaults to `inline`). */
        readonly usage?: "inline" | "frame" | "standalone" | "preview";
        /** Specifies the operation mode (`paginated` by default). */
        readonly mode?: "paginated" | "continuous" | "progressive";
        /** Specifies a function that is invoked when the collector is rendered. */
        readonly onReady?: (collector: Collector) => void;
        /** Invoked when there is a change. */
        readonly onChange?: (collector: Collector) => void;
        /** Invoked when there is a data change. */
        readonly onData?: (collector: Collector) => void;
        /** Specifies a function that is invoked when the collector wants to pause. */
        readonly onPause?: (snapshot: ISnapshot<ICollectorSnapshot>, collector: Collector) => Promise<void> | boolean | void;
        /** Specifies a function that is invoked when the collector is finished. */
        readonly onFinish?: (instance: Instance) => Promise<void> | boolean | void;
        /** Specifies a function that is invoked when the edit button of a block in preview mode is clicked. */
        readonly onEdit?: (nodeId: string) => void;
        /** Specifies attachment related settings. */
        readonly onAttachment?: {
            /** Specifies the function to retrieve an attachment. */
            get: (file: string) => Promise<Blob>;
            /** Specifies the function that is invoked when a file is attached. */
            put: (file: File, onProgress: (percent?: number) => void) => Promise<string>;
            /** Specifies the function that is invoked when an attachment is deleted. */
            delete: (file: string) => Promise<void>;
        };
    }> {
        readonly element: React.RefObject<HTMLElement>;
        readonly state: ICollectorState;
        /** Retrieves the definition. */
        readonly definition: IDefinition | undefined;
        /** Retrieves the name of the definition. */
        readonly name: string;
        /** Retrieves if the collector is empty. */
        readonly isEmpty: boolean;
        /** Retrieves if the collector is running. */
        readonly isRunning: boolean;
        /** Retrieves if the collector is stopped. */
        readonly isStopped: boolean;
        /** Retrieves if the collector has finished (without pausing or stopping it). */
        readonly isFinished: boolean;
        /** Retrieves if the collector is reloading. */
        readonly isReloading: boolean;
        /** Sets the styles. */
        styles: ICollectorStyles;
        /** Sets the localization information. */
        l10n: IL10n;
        /** Sets the current overrides. */
        overrides: ICollectorOverrides;
        /** Sets the current view mode. */
        view: "normal" | "preview" | "test";
        /** Sets the current operation mode. */
        mode: "paginated" | "continuous" | "progressive";
        render(): React.ReactNode;
        componentDidMount(): void;
        componentDidUpdate(): void;
        componentWillUnmount(): void;
        /** Start the collector. */
        start(): void;
        /** Resume a collector that was previously paused. */
        resume(snapshot: ISnapshot<ICollectorSnapshot>): boolean;
        /** Pause the collector. */
        pause(): ISnapshot<ICollectorSnapshot> | undefined | Promise<ISnapshot<ICollectorSnapshot>>;
        /** Stop the collector. */
        stop(): void;
        /** Restarts the collector. */
        restart(): void;
        /** Reload with a new definition. */
        reload(definition: IDefinition): void;
        /** Call this function when the parent element is resized. */
        resize(): void;
        /** Shows the pause dialog. */
        requestPauseDialog(
            snapshot: ISnapshot<ICollectorSnapshot>,
            onPause: (snapshot: ISnapshot<ICollectorSnapshot>, emailAddress: string) => Promise<void> | boolean | void
        ): Promise<void>;
        /** Request a preview of the specified node. */
        preview(nodeId: string): void;
    }
}

declare module "tripetto-collector-standard-bootstrap/styles/interface" {
    import { IStyles } from "tripetto-collector";
    export type TFonts =
        | ""
        | "Arial, Helvetica, Sans-Serif"
        | "Arial Black, Gadget, Sans-Serif"
        | "Comic Sans MS, Textile, Cursive, Sans-Serif"
        | "Courier New, Courier, Monospace"
        | "Georgia, Times New Roman, Times, Serif"
        | "Impact, Charcoal, Sans-Serif"
        | "Lucida Console, Monaco, Monospace"
        | "Lucida Sans Unicode, Lucida Grande, Sans-Serif"
        | "Palatino Linotype, Book Antiqua, Palatino, Serif"
        | "Tahoma, Geneva, Sans-Serif"
        | "Times New Roman, Times, Serif"
        | "Trebuchet MS, Helvetica, Sans-Serif"
        | "Verdana, Geneva, Sans-Serif";
    export type TBootstrapStyles = "primary" | "secondary" | "success" | "info" | "warning" | "danger" | "light" | "dark";
    export type TBootstrapStylesOutline =
        | "outline-primary"
        | "outline-secondary"
        | "outline-success"
        | "outline-info"
        | "outline-warning"
        | "outline-danger"
        | "outline-light"
        | "outline-dark";
    export interface ICollectorStyles extends IStyles {
        readonly backgroundColor?: string;
        readonly textFont?: TFonts;
        readonly textColor?: string;
        readonly mode?: "paginated" | "continuous" | "progressive";
        readonly showEnumerators?: boolean;
        readonly showPageIndicators?: boolean;
        readonly showProgressbar?: boolean;
        readonly backgroundImage?: {
            readonly url: string;
            readonly size: "auto" | "100% auto" | "auto 100%" | "cover" | "contain" | "repeat";
        };
        readonly form?: {
            readonly inputStyle: TBootstrapStyles;
            readonly unselectedStyle: TBootstrapStyles | TBootstrapStylesOutline;
            readonly selectedStyle: TBootstrapStyles | TBootstrapStylesOutline;
            readonly neutralStyle: TBootstrapStyles | TBootstrapStylesOutline;
            readonly positiveStyle: TBootstrapStyles | TBootstrapStylesOutline;
            readonly negativeStyle: TBootstrapStyles | TBootstrapStylesOutline;
        };
        readonly buttons?: {
            readonly nextStyle: TBootstrapStyles | TBootstrapStylesOutline;
            readonly nextLabel?: string;
            readonly backStyle: TBootstrapStyles | TBootstrapStylesOutline;
            readonly backLabel?: string;
            readonly completeStyle: TBootstrapStyles | TBootstrapStylesOutline;
            readonly completeLabel?: string;
            readonly pauseStyle: TBootstrapStyles | TBootstrapStylesOutline;
        };
        readonly navigation?: {
            readonly progressbarStyle: TBootstrapStyles;
            readonly paginationStyle: TBootstrapStyles;
        };
    }
}

declare module "tripetto-collector-standard-bootstrap/interfaces/overrides" {
    export interface ICollectorOverrides {
        readonly removeBranding?: boolean;
        readonly confirmationTitle?: string;
        readonly confirmationSubtitle?: string;
        readonly confirmationText?: string;
        readonly confirmationImage?: string;
        readonly confirmationButton?:
            | {
                  readonly label: string;
                  readonly url: string;
              }
            | "off";
    }
}

declare module "tripetto-collector-standard-bootstrap/interfaces/snapshot" {
    export interface ICollectorSnapshot {
        readonly b?: {
            [key: string]: false | true | undefined;
        };
    }
}

declare module "tripetto-collector-standard-bootstrap/interfaces/renderer" {
    import { NodeBlock } from "tripetto-collector";
    import { IBlockHelper } from "tripetto-collector-standard-bootstrap/interfaces/block";
    export interface IBlockRenderer extends NodeBlock {
        render: (block: IBlockHelper) => React.ReactNode;
    }
}

declare module "tripetto-collector-standard-bootstrap/interfaces/block" {
    import * as React from "react";
    import { ICollectorStyles } from "styles/interface";
    export interface IBlockHelper {
        /** Contains the style. */
        styles: ICollectorStyles;
        /** Parsed markdown name. */
        name: (required?: boolean, labelFor?: string) => React.ReactNode;
        /** Parsed markdown description. */
        description: React.ReactNode;
        /** Parsed image. */
        imageFromURL: (imageURL?: string, imageWidth?: string) => React.ReactNode;
        /** Parsed markdown explanation. */
        explanation: (label?: string) => React.ReactNode;
        /** Parsed markdown placeholder. */
        placeholder: string;
        /** Parsed markdown placeholder or name (single line). */
        placeholderOrName: (required?: boolean) => React.ReactNode;
        /** Tab-index for the block. */
        tabIndex: number;
        /** Specifies if the block validation failed. */
        isFailed: boolean;
        /** Updates a block. */
        update: () => void;
        /** The block gets focus. */
        onFocus: () => void;
        /** The block loses focus. */
        onBlur: () => void;
        /** Specifies the function that is invoked when a file is attached. */
        onAttachment?: {
            get: (file: string) => Promise<Blob>;
            put: (file: File, onProgress: (percent?: number) => void) => Promise<string>;
            delete: (file: string) => Promise<void>;
        };
    }
}

declare module "tripetto-collector-standard-bootstrap/components/pause" {
    import { Collector } from "tripetto-collector-standard-bootstrap/collector";
    import { ISnapshot } from "tripetto-collector";
    import { ICollectorStyles } from "tripetto-collector-standard-bootstrap/styles/interface";
    import { ICollectorSnapshot } from "tripetto-collector-standard-bootstrap/interfaces/snapshot";
    export const pauseDialog: (
        state: boolean | "error" | "pausing" | "awaiting",
        styles: ICollectorStyles,
        callbacks: {
            pause: (emailAddress: string) => void;
            close: () => void;
        }
    ) => JSX.Element;
    export const usePauseToEmailDialog: (
        onPause: (snapshot: ISnapshot<ICollectorSnapshot>, emailAddress: string) => boolean | void | Promise<void>
    ) => (snapshot: ISnapshot<ICollectorSnapshot>, collector: Collector) => Promise<void>;
}

declare module "tripetto-collector-standard-bootstrap/run" {
    import { IDefinition, IL10n, ILocale, ISnapshot, Instance, TTranslation } from "tripetto-collector";
    import { Collector } from "tripetto-collector-standard-bootstrap/collector";
    import { ICollectorStyles } from "tripetto-collector-standard-bootstrap/styles/interface";
    import { ICollectorOverrides } from "tripetto-collector-standard-bootstrap/interfaces/overrides";
    import { ICollectorSnapshot } from "tripetto-collector-standard-bootstrap/interfaces/snapshot";
    import * as React from "react";
    export function run(props: {
        /** Specifies the parent element for the collector. */
        readonly element: HTMLElement | null;
        /** Specifies the definition to run. */
        readonly definition?: IDefinition | Promise<IDefinition | undefined>;
        /** Specifies the snapshot that should be restored. */
        readonly snapshot?: ISnapshot<ICollectorSnapshot> | Promise<ISnapshot<ICollectorSnapshot> | undefined>;
        /** Specifies the styles. */
        readonly styles?: ICollectorStyles | Promise<ICollectorStyles | undefined>;
        /** Specifies the localization information. */
        readonly l10n?: IL10n | Promise<IL10n | undefined>;
        /** Specifies the overrides for the collector. */
        readonly overrides?: ICollectorOverrides | Promise<ICollectorOverrides | undefined>;
        /** Specifies the view mode (`normal` by default). */
        readonly view?: "normal" | "preview" | "test";
        /** Specifies how the collector is used (defaults to `inline`). */
        readonly usage?: "inline" | "frame" | "standalone" | "preview";
        /** Specifies the operation mode (`paginated` by default). */
        readonly mode?: "paginated" | "continuous" | "progressive";
        /** Specifies if the collector needs to be automatically resized when the host window is resized. */
        readonly autoResize?: boolean;
        /** Specifies a React ref for the collector component. */
        readonly ref?: React.RefObject<Collector>;
        /** Invoked when the collector wants to load locale information. */
        readonly onLocale?: (locale: string) => ILocale | Promise<ILocale | undefined> | undefined;
        /** Invoked when the collector wants to load a translation. */
        readonly onTranslation?: (
            language: string,
            context: string
        ) => TTranslation | TTranslation[] | Promise<TTranslation | TTranslation[] | undefined> | undefined;
        /** Specifies a function that is invoked when the collector is rendered. */
        readonly onReady?: (collector: Collector) => void;
        /** Invoked when there is a change. */
        readonly onChange?: (collector: Collector) => void;
        /** Invoked when there is a data change. */
        readonly onData?: (collector: Collector) => void;
        /** Specifies a function that is invoked when the collector wants to pause. */
        readonly onPause?: (snapshot: ISnapshot<ICollectorSnapshot>, collector: Collector) => Promise<void> | boolean | void;
        /** Specifies a function that is invoked when the collector is finished. */
        readonly onFinish?: (instance: Instance) => Promise<void> | boolean | void;
        /** Specifies a function that is invoked when the edit button of a block in preview mode is clicked. */
        readonly onEdit?: (nodeId: string) => void;
        /** Specifies attachment related settings. */
        readonly onAttachment?: {
            /** Specifies the function to retrieve an attachment. */
            get: (file: string) => Promise<Blob>;
            /** Specifies the function that is invoked when a file is attached. */
            put: (file: File, onProgress: (percent?: number) => void) => Promise<string>;
            /** Specifies the function that is invoked when an attachment is deleted. */
            delete: (file: string) => Promise<void>;
        };
    }): Promise<{
        /** A reference to the collector component. */
        readonly collector: Collector;
        /** Specifies the definition. */
        definition: IDefinition;
        /** Specifies the styles. */
        styles: ICollectorStyles;
        /** Specifies the localization settings. */
        l10n: IL10n;
        /** Specifies the overrides. */
        overrides: ICollectorOverrides;
        /** Specifies the view mode. */
        view: "normal" | "preview" | "test";
        /** Specifies the operation mode. */
        mode: "paginated" | "continuous" | "progressive";
        /** Retrieves the height of the content in pixels. */
        readonly height: number;
        /** Request a preview of specified node. */
        readonly preview: (nodeId: string) => void;
        /** Pauses the collector. */
        readonly pause: () => ISnapshot<ICollectorSnapshot> | undefined | Promise<ISnapshot<ICollectorSnapshot>>;
        /** Indicates the parent element is resized. */
        readonly resize: () => void;
        /** Destroys the component. */
        readonly destroy: () => void;
    }>;
}

declare module "tripetto-collector-standard-bootstrap/interfaces/state" {
    import { ICollectorStyles } from "tripetto-collector-standard-bootstrap/styles/interface";
    import { ICollectorOverrides } from "tripetto-collector-standard-bootstrap/interfaces/overrides";
    import { IL10n } from "tripetto-collector";
    export interface ICollectorState {
        styles: ICollectorStyles;
        l10n: IL10n;
        overrides: ICollectorOverrides;
        view: "normal" | "preview" | "test";
        mode: "paginated" | "continuous" | "progressive";
        changes: number;
        focus: {
            [key: string]: boolean | undefined;
        };
        activate?: string;
        isFinished: boolean | "finishing" | "error";
        isPaused: boolean | "pausing" | "awaiting" | "error";
        pauseDialog?: {
            pause: (emailAddress: string) => void;
            close: () => void;
        };
    }
}
